@@ -1,4 +1,4 @@
-/* $Id: irplib_polynomial-test.c,v 1.37 2013/01/29 08:43:33 jtaylor Exp $
+/* $Id: irplib_polynomial-test.c,v 1.37 2013-01-29 08:43:33 jtaylor Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2004 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: jtaylor $
- * $Date: 2013/01/29 08:43:33 $
+ * $Date: 2013-01-29 08:43:33 $
  * $Revision: 1.37 $
- * $Name: sinfo-2_4_0 $
+ * $Name: not supported by cvs2svn $
  */
 
 /*-----------------------------------------------------------------------------
@@ -36,6 +36,7 @@
 #include <irplib_polynomial.h>
 #include <math.h>
 #include <float.h>
+#include <stdint.h>
 
 /*-----------------------------------------------------------------------------
                                    Defines
@@ -202,11 +203,17 @@ static void irplib_polynomial_solve_1d_all_test(void)
                                         DBL_EPSILON, 2.0*DBL_EPSILON);
 
         /* A more extreme case: Same with negative roots */
-        (void)cpl_vector_fill(xtrue, -2.0e-3 * FLT_EPSILON);
+#if defined SIZE_MAX && SIZE_MAX <= 4294967295
+        /* Fails on 32-bit - also w. -0.1 * FLT_EPSILON */
+#else
+        (void)cpl_vector_fill(xtrue, -0.2 * FLT_EPSILON);
+
         (void)cpl_vector_set(xtrue, 0, -1.0);
 
         irplib_polynomial_test_root_all(xtrue, nreal, CPL_MATH_PI,
                                         FLT_EPSILON, 3.0*DBL_EPSILON);
+#endif
+
 
         if (nreal != 3) {
             /* The most extreme case: Same with negative roots */
@@ -488,9 +495,9 @@ cpl_error_code irplib_polynomial_multiply_1d_factor(cpl_polynomial * self,
 
         irplib_polynomial_multiply_1d_factor(self, aroot, 2);
 
-        irplib_polynomial_multiply_scalar(copy, copy, b * b);
+        cpl_polynomial_multiply_scalar(copy, copy, b * b);
 
-        irplib_polynomial_add(self, self, copy);
+        cpl_polynomial_add(self, self, copy);
 
         cpl_vector_delete(aroot);
         cpl_polynomial_delete(copy);
