@@ -19,13 +19,10 @@
 
 /*
  * $Author: amodigli $
- * $Date: 2012/03/02 08:42:20 $
+ * $Date: 2012-03-02 08:42:20 $
  * $Revision: 1.3 $
- * $Name: sinfo-2_4_0 $
- * $Log: sinfo_baryvel.c,v $
- * Revision 1.3  2012/03/02 08:42:20  amodigli
- * fixed some typos on doxygen
- *
+ * $Name: not supported by cvs2svn $
+ * $Log: not supported by cvs2svn $
  * Revision 1.2  2009/04/28 11:42:18  amodigli
  * now return cpl_error_code
  *
@@ -448,7 +445,8 @@ void barvel(double DJE, double DEQ,
   double DCOSLS,DSINEP,DCOSEP;
   double forbel[8], sorbel[18], sinlp[5], coslp[5];
   double SINLM,COSLM,SIGMA;
-  int IDEQ,K,N;
+  /* int IDEQ; */
+  int K,N;
 
   double *E = sorbel + 1 - 1;
   double *G = forbel + 1 - 1;
@@ -555,7 +553,9 @@ void barvel(double DJE, double DEQ,
 
   double DC1MME = 0.99999696E0;
 
-  IDEQ=DEQ;
+  /* not used later
+   * IDEQ=DEQ; */
+
 
   DT=(DJE-DCT0)/DCJUL;
 
