@@ -57,7 +57,7 @@
 *       an image with at least one continuum spectrum of a pinhole
 *       this is done by searching the spectrum within the image
 *       then fitting the spectrum along the rows within a given box
-*       by a sinfo_gaussian, so that the exact position is determined for
+*       by a Gaussian, so that the exact position is determined for
 *       each row. Afterwards, a straight line is fitted through the
 *       fitted positions. The slope of this linear fit is returned.
 *   2)  shifts the rows of a raw image by using the output of 
@@ -69,7 +69,7 @@
 *       an image with at least one continuum spectrum of a pinhole.
 *       this is done by searching the spectrum within the image
 *       then fitting the spectrum along the rows within a given box
-*       by a sinfo_gaussian, so that the exact position is determined for
+*       by a Gaussian, so that the exact position is determined for
 *       each row. Afterwards, a polynomial is fitted through the
 *       found positions. The polynomial coefficients are returned.
 *
@@ -122,7 +122,7 @@
 
 /**
    @name   sinfo_new_slope_of_spectrum()
-   @memo determines the sub-pixel shifts of each row
+   @memo   determines the sub-pixel shifts of each row
    @param  ns_image   image with at least one continuum spectrum of a pinhole
    @param  box_length width of the box in which the lines are fit by a Gaussian
    @param  fwhm       first guess of the full width at half maximum
@@ -266,7 +266,7 @@ sinfo_new_slope_of_spectrum( cpl_image * ns_image,
         wdat = (float *) cpl_calloc( line -> n_elements, sizeof (float) ) ;
         mpar = (int *)   cpl_calloc( MAXPAR, sizeof (int) ) ;
         dec_par = sinfo_new_fit_params(1) ;
-    par = dec_par[0];
+        par = dec_par[0];
 
         counter = 0 ;
         bad_ind = 0 ;
@@ -455,7 +455,7 @@ sinfo_new_slope_of_spectrum( cpl_image * ns_image,
    @param image   raw image in which the rows should be shifted
    @param slope   slope of a fitted straight line along a spectrum
                   output of sinfo_slopeOfSpectrum
-   @param n_order order of the interpolation polynom
+   @param n_order order of the interpolation polynomial
    @return resulting image with shifted rows
    @doc   shifts the rows of a raw image by using the output of
           sinfo_slopeOfSpectrum and applying polynomial interpolation
@@ -487,8 +487,10 @@ sinfo_new_shift_rows( cpl_image * image,
     int flag=0;
     int ilx=0;
     int ily=0;
+    /*
     int olx=0;
     int oly=0;
+    */
     float* pidata=NULL;
     float* podata=NULL;
 
@@ -513,8 +515,10 @@ sinfo_new_shift_rows( cpl_image * image,
     returnImage = cpl_image_duplicate( image ) ;
     ilx=cpl_image_get_size_x(image);
     ily=cpl_image_get_size_y(image);
+    /*
     olx=cpl_image_get_size_x(returnImage);
     oly=cpl_image_get_size_y(returnImage);
+    */
     pidata=cpl_image_get_data_float(image);
     podata=cpl_image_get_data_float(returnImage);
 
