@@ -1,4 +1,4 @@
-/* $Id: sinfo_distortion.c,v 1.37 2012/03/05 16:34:06 amodigli Exp $
+/* $Id: sinfo_distortion.c,v 1.37 2012-03-05 16:34:06 amodigli Exp $
  *
  * This file is part of the irplib package
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: amodigli $
- * $Date: 2012/03/05 16:34:06 $
+ * $Date: 2012-03-05 16:34:06 $
  * $Revision: 1.37 $
- * $Name: sinfo-2_4_0 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -331,7 +331,7 @@ cpl_polynomial * sinfo_distortion_estimate_new(
     cpl_bivector    *   grid_tmp ;
     cpl_vector* grid_tot=0;
     double* pgrid_tmp_x=NULL;
-    double* pgrid_tmp_y=NULL;
+    //double* pgrid_tmp_y=NULL;
     double* pgrid_tot=NULL;
     double* plines_pos_tmp=NULL;
     int n_lines=0;
@@ -444,7 +444,7 @@ cpl_polynomial * sinfo_distortion_estimate_new(
     grid_tmp=cpl_bivector_duplicate(grid);
     grid_tot=cpl_vector_new(n_calib);
     pgrid_tmp_x = cpl_bivector_get_x_data(grid_tmp) ;
-    pgrid_tmp_y = cpl_bivector_get_y_data(grid_tmp) ;
+    //pgrid_tmp_y = cpl_bivector_get_y_data(grid_tmp) ;
     pgrid_tot = cpl_vector_get_data(grid_tot);
     for(j=0;j<n_calib;j++) {
       pgrid_tot[j]=0;
@@ -730,7 +730,7 @@ cpl_polynomial * sinfo_distortion_estimate(
     int k=0;
     cpl_vector* grid_tot=0;
     double* pgrid_tmp_x=NULL;
-    double* pgrid_tmp_y=NULL;
+    //double* pgrid_tmp_y=NULL;
     double* pgrid_tot=NULL;
     double* plines_pos_tmp=NULL;
 
@@ -836,7 +836,7 @@ cpl_polynomial * sinfo_distortion_estimate(
     grid_tmp=cpl_bivector_duplicate(grid);
     grid_tot=cpl_vector_new(n_calib);
     pgrid_tmp_x = cpl_bivector_get_x_data(grid_tmp) ;
-    pgrid_tmp_y = cpl_bivector_get_y_data(grid_tmp) ;
+    //pgrid_tmp_y = cpl_bivector_get_y_data(grid_tmp) ;
     pgrid_tot = cpl_vector_get_data(grid_tot);
     for(j=0;j<n_calib;j++) {
       pgrid_tot[j]=0;
@@ -1300,9 +1300,7 @@ sinfo_distortion_get_arc_positions(
     int                 obj ;
     int                 nx, ny ;
     int                 i, j, k ;
-#if defined CPL_VERSION_CODE && CPL_VERSION_CODE >= CPL_VERSION(4, 8, 0)
     cpl_mask*          mask=NULL;
-#endif
 
     /* Check entries */
 
@@ -1318,15 +1316,12 @@ sinfo_distortion_get_arc_positions(
     /* Median filter on input image */
     kernel = cpl_matrix_new(3, 3) ;
     cpl_matrix_fill(kernel, 1.0) ;
-#if defined CPL_VERSION_CODE && CPL_VERSION_CODE >= CPL_VERSION(4, 8, 0)
     filt_img=cpl_image_duplicate(in);
     mask=cpl_mask_new(3,3);
     cpl_mask_not(mask);
     cpl_image_filter_mask(filt_img,in,mask,CPL_FILTER_MEDIAN,CPL_BORDER_FILTER);
     cpl_mask_delete(mask);
-#else
-    filt_img = cpl_image_filter_median(in, kernel) ;
-#endif
+
     cpl_matrix_delete(kernel) ;
 
     /* Measured Arcs coordinates along curvature */
@@ -1410,7 +1405,7 @@ sinfo_distortion_fine_pos(
     double      max ;
     double      val ;
     int         maxpos ;
-    int         im_extrem ;
+    //int         im_extrem ;
     double      arc_pos ;
     int         nx ;
 
@@ -1424,7 +1419,7 @@ sinfo_distortion_fine_pos(
     max    = (double)pim[start_pos + y * nx] ;
     plabel_im = cpl_image_get_data_int(label_im) ;
     objnum = plabel_im[start_pos + y * nx] ;
-    im_extrem = nx ;
+    //im_extrem = nx ;
 
     /* While we stay in the same object... */
     do {
