@@ -962,6 +962,7 @@ sinfo_new_fit_2d_gaussian ( cpl_image   * image,
     int ily=0;
     float* pidata=NULL;
 
+    memset(&wdat[0], 0, (4*halfbox_x*halfbox_y)* sizeof(double));
 
     if ( NULL == image )
     {
@@ -1473,7 +1474,7 @@ float sinfo_new_determine_conversion_factor ( cpl_imagelist * cube,
 
     int ilx=0;
     int ily=0;
-    int inp=0;
+    //int inp=0;
 
     if ( NULL == cube )
     {
@@ -1483,7 +1484,7 @@ float sinfo_new_determine_conversion_factor ( cpl_imagelist * cube,
 
     ilx=cpl_image_get_size_x(cpl_imagelist_get(cube,0));
     ily=cpl_image_get_size_y(cpl_imagelist_get(cube,0));
-    inp=cpl_imagelist_get_size(cube);
+    //inp=cpl_imagelist_get_size(cube);
 
     if ( halfbox_x <= 0 || halfbox_y <= 0 || 
        2*halfbox_x > ilx || 2*halfbox_y > ily)
