@@ -17,7 +17,7 @@
  * Foundation, 51 Franklin St, Fifth Floor, Boston, MA  02111-1307  USA
  */
 /*----------------------------------------------------------------------------
-   
+
    File name     :    function_1d.c
    Author         :    Nicolas Devillard
    Created on    :    Tue, Sept 23 1997    
@@ -25,9 +25,9 @@
 
  ---------------------------------------------------------------------------*/
 /*
- $Id: sinfo_function_1d.c,v 1.7 2012/03/02 08:42:20 amodigli Exp $
+ $Id: sinfo_function_1d.c,v 1.7 2012-03-02 08:42:20 amodigli Exp $
  $Author: amodigli $
- $Date: 2012/03/02 08:42:20 $
+ $Date: 2012-03-02 08:42:20 $
  $Revision: 1.7 $
  */
 
@@ -66,10 +66,10 @@ static double * function1d_generate_smooth_kernel(int filt_type, int hw);
 
 static int
 function1d_search_value(
-    pixelvalue  *   x,
-    int             len,
-    pixelvalue      key,
-    int         *   foundPtr
+                pixelvalue  *   x,
+                int             len,
+                pixelvalue      key,
+                int         *   foundPtr
 ) ;
 
 /*----------------------------------------------------------------------------
@@ -159,8 +159,8 @@ sinfo_function1d_dup(pixelvalue * arr, int ns)
  */
 double
 sinfo_function1d_find_centroid(
-    pixelvalue    *    line,    /*    the input line    */
-    int    npix    /*     number of pixels in this line    */
+                pixelvalue    *    line,    /*    the input line    */
+                int    npix    /*     number of pixels in this line    */
 )
 {
     pixelvalue    max ;
@@ -189,7 +189,7 @@ sinfo_function1d_find_centroid(
     centroid = 0.0 ;
     weights  = 0.0 ;
     for (i=maxpos-HALF_CENTROID_DOMAIN; 
-            i<=maxpos+HALF_CENTROID_DOMAIN; i++) {
+                    i<=maxpos+HALF_CENTROID_DOMAIN; i++) {
         centroid += (double)line[i] * (double)i ;
         weights  += (double)line[i] ;
     }
@@ -222,10 +222,10 @@ sinfo_function1d_find_centroid(
 
 double
 sinfo_function1d_find_locmax(
-    pixelvalue    *    line,
-    int                npix,
-    int                where,
-    int                hs
+                pixelvalue    *    line,
+                int                npix,
+                int                where,
+                int                hs
 )
 {
     pixelvalue    max ;
@@ -237,7 +237,7 @@ sinfo_function1d_find_locmax(
     if ((where<hs) || (where>(npix-hs-1))) {
         return (double)-1.0 ;
     }
-    
+
     /*
      * Search for the closest local maximal around the requested range.
      */
@@ -295,10 +295,10 @@ sinfo_function1d_find_locmax(
 
 pixelvalue *
 sinfo_function1d_filter_lowpass(
-    pixelvalue    *    input_sig,
-    int                samples,
-    int                filter_type,
-    int                hw
+                pixelvalue    *    input_sig,
+                int                samples,
+                int                filter_type,
+                int                hw
 )
 {
     pixelvalue    *    out_sig ;
@@ -379,14 +379,14 @@ function1d_generate_smooth_kernel(int filt_type, int hw)
 
     switch(filt_type) {
 
-        case LOW_PASS_LINEAR:
+    case LOW_PASS_LINEAR:
         for (i=-hw ; i<=hw ; i++) {
             /* flat kernel */
             kernel[hw+i] = 1.0 / (double)(2*hw+1) ;
         }
         break ;
 
-        case LOW_PASS_GAUSSIAN:
+    case LOW_PASS_GAUSSIAN:
         norm = 0.00 ;
         for (i=-hw ; i<=hw ; i++) {
             /* sinfo_gaussian kernel */
@@ -398,9 +398,9 @@ function1d_generate_smooth_kernel(int filt_type, int hw)
         }
         break ;
 
-        default:
+    default:
         sinfo_msg_error("unrecognized low pass filter: "
-                                "cannot generate kernel") ;
+                        "cannot generate kernel") ;
         return (double*)NULL ;
         break ;
     }
@@ -428,9 +428,9 @@ function1d_generate_smooth_kernel(int filt_type, int hw)
 
 pixelvalue * 
 sinfo_function1d_median_smooth(
-    pixelvalue * list,
-    int          np,
-    int             hw)
+                pixelvalue * list,
+                int          np,
+                int             hw)
 {
     int             i,j ;
     pixelvalue    *    row ;
@@ -477,19 +477,19 @@ sinfo_function1d_median_smooth(
 
 pixelvalue * 
 sinfo_function1d_remove_lowfreq(
-    pixelvalue * pixel_signal,
-    int             ns)
+                pixelvalue * pixel_signal,
+                int             ns)
 {
     pixelvalue    *    sig_in ;
     pixelvalue    *    smooth ;
     int                i ;
-    
-    
+
+
     /* Apply severe low-pass filter several times */
     sig_in = sinfo_function1d_dup(pixel_signal, ns);
     for (i=0 ; i<LOWFREQ_PASSES ; i++) {
         smooth = sinfo_function1d_filter_lowpass( sig_in, ns, 
-                         LOW_PASS_LINEAR, 5);
+                        LOW_PASS_LINEAR, 5);
         cpl_free(sig_in);
         sig_in = smooth ;
     }
@@ -528,24 +528,24 @@ sinfo_function1d_remove_lowfreq(
 
 pixelvalue * 
 sinfo_function1d_remove_thermalbg(
-    pixelvalue * pixel_signal,
-    int             ns)
+                pixelvalue * pixel_signal,
+                int             ns)
 {
     pixelvalue    *    smooth ;
     int                i ;
-    
+
     int                nmin ;
     pixelvalue        lef[2], rig[2];
 
     pixelvalue    *    x,
-                *    y,
-                *    spl_x,
-                *    spl_y ;
+    *    y,
+    *    spl_x,
+    *    spl_y ;
     double            med_y ;
     double            avg2med ;
     double            dist ;
 
-    
+
     /* Detect all local minima */
     nmin = 0 ;
     x = sinfo_function1d_new(ns);
@@ -558,9 +558,9 @@ sinfo_function1d_remove_thermalbg(
         rig[1] = pixel_signal[i+2];
 
         if ( (pixel_signal[i] < lef[0]) &&
-             (pixel_signal[i] < lef[1]) &&
-             (pixel_signal[i] < rig[0]) &&
-             (pixel_signal[i] < rig[1])) {
+                        (pixel_signal[i] < lef[1]) &&
+                        (pixel_signal[i] < rig[0]) &&
+                        (pixel_signal[i] < rig[1])) {
             x[nmin] = (pixelvalue)i ;
             y[nmin] = pixel_signal[i];
             nmin ++ ;
@@ -634,12 +634,12 @@ sinfo_function1d_remove_thermalbg(
 
 void 
 sinfo_function1d_interpolate_linear(
-    pixelvalue    *    x,
-    pixelvalue    *    y,
-    int                len,
-    pixelvalue    *    spl_x,
-    pixelvalue    *    spl_y,
-    int                spl_len
+                pixelvalue    *    x,
+                pixelvalue    *    y,
+                int                len,
+                pixelvalue    *    spl_x,
+                pixelvalue    *    spl_y,
+                int                spl_len
 )
 {
     double        a, b ;
@@ -659,7 +659,7 @@ sinfo_function1d_interpolate_linear(
             spl_y[i] = 0.0;
         } else {
             a = ((double)y[j+1]-(double)y[j]) /
-                ((double)x[j+1]-(double)x[j]);
+                            ((double)x[j+1]-(double)x[j]);
             b = (double)y[j] - a * (double)x[j] ;
             spl_y[i] = (pixelvalue)(a * (double)spl_x[i] + b) ;
         }
@@ -685,15 +685,15 @@ sinfo_function1d_interpolate_linear(
 
 static int
 function1d_search_value(
-    pixelvalue    *    x,
-    int             len,
-    pixelvalue         key,
-    int         *    foundPtr
+                pixelvalue    *    x,
+                int             len,
+                pixelvalue         key,
+                int         *    foundPtr
 )
 {
     int    high,
-        low,
-        middle;
+    low,
+    middle;
 
     low  = 0;
     high = len - 1;
@@ -740,30 +740,30 @@ function1d_search_value(
 
 int
 sinfo_function1d_natural_spline(
-    pixelvalue    *     x,
-    pixelvalue    *     y,
-    int             len,
-    pixelvalue    *     splX,
-    pixelvalue    *     splY,
-    int             splLen
+                pixelvalue    *     x,
+                pixelvalue    *     y,
+                int             len,
+                pixelvalue    *     splX,
+                pixelvalue    *     splY,
+                int             splLen
 )
 {
     int             end;
     int             loc,
-                    found;
+    found;
     register int     i,
-                    j,
-                    n;
+    j,
+    n;
     double         *    h; /* sinfo_vector of deltas in x */
     double         *    alpha;
     double         *    l,
-                *    mu,
-                *    z,
-                *    a,
-                *    b,
-                *    c,
-                *    d,
-                    v;
+    *    mu,
+    *    z,
+    *    a,
+    *    b,
+    *    c,
+    *    d,
+    v;
 
     end = len - 1;
 
@@ -794,7 +794,7 @@ sinfo_function1d_natural_spline(
     for (n = 0, i = 1; i < end; i++, n++) {
         /* n = i - 1 */
         alpha[i] = 3.0 * ((a[i+1] / h[i]) - (a[i] / h[n]) - (a[i] / h[i]) +
-                  (a[n] / h[n]));
+                        (a[n] / h[n]));
     }
 
     /* Vectors to solve the tridiagonal sinfo_matrix */
@@ -819,24 +819,24 @@ sinfo_function1d_natural_spline(
 
     /* Now calculate the new values */
     for (j = 0; j < splLen; j++) {
-         v = (double)splX[j];
-     splY[j] = (pixelvalue)0;
+        v = (double)splX[j];
+        splY[j] = (pixelvalue)0;
 
-     /* Is it outside the interval? */
-     if ((v < (double)x[0]) || (v > (double)x[end])) {
-        continue;
-     }
-     /* Search for the interval containing v in the x sinfo_vector */
-     loc = function1d_search_value(x, len, (pixelvalue)v, &found);
-     if (found) {
-        splY[j] = y[loc];
-     } else {
-        loc--;
-        v -= (double)x[loc];
-        splY[j] = (pixelvalue)(    a[loc] +
-                        v * (b[loc] +
-                   v * (c[loc] +
-                    v * d[loc])));
+        /* Is it outside the interval? */
+        if ((v < (double)x[0]) || (v > (double)x[end])) {
+            continue;
+        }
+        /* Search for the interval containing v in the x sinfo_vector */
+        loc = function1d_search_value(x, len, (pixelvalue)v, &found);
+        if (found) {
+            splY[j] = y[loc];
+        } else {
+            loc--;
+            v -= (double)x[loc];
+            splY[j] = (pixelvalue)(    a[loc] +
+                            v * (b[loc] +
+                                            v * (c[loc] +
+                                                            v * d[loc])));
         }
     }
     cpl_free(a) ;
@@ -863,10 +863,10 @@ sinfo_function1d_natural_spline(
 
 pixelvalue
 sinfo_function1d_average_reject(
-    pixelvalue    *    line,
-    int                npix,
-    int                pix_low,
-    int                pix_high)
+                pixelvalue    *    line,
+                int                npix,
+                int                pix_low,
+                int                pix_high)
 {
     pixelvalue    *    sorted ;
     int                i ;
@@ -922,12 +922,12 @@ sinfo_function1d_average_reject(
 
 double 
 sinfo_function1d_xcorrelate(
-    pixelvalue *    line_i,
-    int             width_i,
-    pixelvalue *    line_t,
-    int             width_t,
-    int                half_search,
-    double     *    delta
+                pixelvalue *    line_i,
+                int             width_i,
+                pixelvalue *    line_t,
+                int             width_t,
+                int                half_search,
+                double     *    delta
 )
 {
     double * xcorr ;
@@ -971,10 +971,10 @@ sinfo_function1d_xcorrelate(
         nval = 0 ;
         for (i=0 ; i<width_t ; i++) {
             if ((i+step > 0) &&
-                (i+step < width_i)) {
-            xcorr[step-STEP_MIN] += ((double)line_t[i] - mean_t) *
-                                    ((double)line_i[i+step] - mean_i) *
-                                    norm ;
+                            (i+step < width_i)) {
+                xcorr[step-STEP_MIN] += ((double)line_t[i] - mean_t) *
+                                ((double)line_i[i+step] - mean_i) *
+                                norm ;
                 nval++ ;
             }
         }
