@@ -250,8 +250,10 @@ cpl_image * sinfo_new_remove_general_offset( cpl_image * im1,
     int ly1=0;
     int lx2=0;
     int ly2=0;
+    /*
     int lxr=0;
     int lyr=0;
+    */
     int lxt=0;
     int lyt=0;
 
@@ -390,9 +392,10 @@ cpl_image * sinfo_new_remove_general_offset( cpl_image * im1,
     /* now determine the residual image if available */
     if ( res_image != NULL )
     {
-
+       /*
        lxr=cpl_image_get_size_x(res_image);
        lyr=cpl_image_get_size_y(res_image);
+       */
        pirdata=cpl_image_get_data_float(res_image);
 
 
@@ -442,7 +445,8 @@ cpl_image * sinfo_new_remove_regional_tilt ( cpl_image * im1,
     int lyf=0;
 
     float* pi1data=NULL;
-    float* pi2data=NULL;
+    /* float* pi2data=NULL; */
+
     float* pirdata=NULL;
     float* poutdata=NULL;
     float* pfildata=NULL;
@@ -464,7 +468,8 @@ cpl_image * sinfo_new_remove_regional_tilt ( cpl_image * im1,
 
 
     pi1data=cpl_image_get_data_float(im1);
-    pi2data=cpl_image_get_data_float(im2);
+    /* pi2data=cpl_image_get_data_float(im2); */
+
     pirdata=cpl_image_get_data_float(res_image);
 
     if ( lx1 != lx2 || ly1 != ly2 ||
@@ -820,7 +825,7 @@ sinfo_new_remove_residual_tilt ( cpl_image * im2, cpl_image * res_image )
     int ly2=0;
     int rlx=0;
     int rly=0;
-    float* pi2data=NULL;
+    /* float* pi2data=NULL; */
     float* pirdata=NULL;
     float* poutdata=NULL;
     float* ptmpdata=NULL;
@@ -837,7 +842,7 @@ sinfo_new_remove_residual_tilt ( cpl_image * im2, cpl_image * res_image )
     ly2=cpl_image_get_size_y(im2);
     rlx=cpl_image_get_size_x(res_image);
     rly=cpl_image_get_size_y(res_image);
-    pi2data=cpl_image_get_data_float(im2);
+    /* pi2data=cpl_image_get_data_float(im2); */
     pirdata=cpl_image_get_data_float(res_image);
 
     if ( lx2 != rlx || ly2 != rly )
@@ -965,8 +970,10 @@ sinfo_new_remove_residual_offset( cpl_image * im2, cpl_image * res_image )
     int ly2=0;
     int rlx=0;
     int rly=0;
+    /*
     int olx=0;
     int oly=0;
+    */
     float* pi2data=NULL;
     float* pirdata=NULL;
     float* poudata=NULL;
@@ -993,9 +1000,10 @@ sinfo_new_remove_residual_offset( cpl_image * im2, cpl_image * res_image )
 
     out_image = cpl_image_duplicate( im2 ) ;
     poudata=cpl_image_get_data_float(res_image);
+    /*
     olx=cpl_image_get_size_x(res_image);
     oly=cpl_image_get_size_y(res_image);
-
+    */
     column = (pixelvalue *) cpl_calloc ( ly2 , sizeof (pixelvalue *) ) ;
     
     for ( i = 0 ; i < lx2 ; i++ ) /* select one column */
