@@ -105,7 +105,7 @@ int sinfo_new_objnod (const char* plugin_id,cpl_parameterlist* config,
 
     int i=0;
     int n=0;
-    int partind = 0 ;
+    /* int partind = 0 ; */
     int centralpix=0 ;
     int z_siz=0;
     int z_min=0;
@@ -122,16 +122,18 @@ int sinfo_new_objnod (const char* plugin_id,cpl_parameterlist* config,
     float ma=0 ;
     float fcol=0 ;
     float center_x=0;
-    float newcenter_x=0 ;
+    /* float newcenter_x=0 ; */
     float center_y=0;
-    float newcenter_y=0;
+    /* float newcenter_y=0; */
+    /*
     float cd1_1=0;
     float cd1_2=0;
     float cd2_1=0;
     float cd2_2=0;
     float pixelscale=0;
-    float angle=0;
-    float radangle=0;
+    */
+    //float angle=0;
+    //float radangle=0;
     double exptime=0;
 
     float *  correct_dist=NULL ;
@@ -156,7 +158,7 @@ int sinfo_new_objnod (const char* plugin_id,cpl_parameterlist* config,
 
     char * name=NULL ;
     char * partname=NULL;
-    char * partname2=NULL;
+    /* char * partname2=NULL; */
     char file_name[MAX_NAME_SIZE];
     int vllx=0;
     int vlly=0;
@@ -219,8 +221,8 @@ int sinfo_new_objnod (const char* plugin_id,cpl_parameterlist* config,
     {
         if ( NULL != (partname = strtok(cfg->outName, "."))) 
         {
-            partname2 = strtok (NULL, ".") ;
-            partind = 1 ;
+            /* partname2 = strtok (NULL, ".") ;*/
+            /* partind = 1 ; */
         }
     }
 
@@ -259,19 +261,20 @@ int sinfo_new_objnod (const char* plugin_id,cpl_parameterlist* config,
     
     /* get some header values and compute the CD-sinfo_matrix */
         plist=cpl_propertylist_load(name,0);
-    pixelscale = sinfo_pfits_get_pixscale(plist) /2;
-    angle = sinfo_pfits_get_posangle(plist) ;
+    /* pixelscale = sinfo_pfits_get_pixscale(plist) /2; */
+    //angle = sinfo_pfits_get_posangle(plist) ;
         /* in PUPIL data there is not posangle info: we reset the error */
         if(cpl_error_get_code() != CPL_ERROR_NONE) {
       cpl_error_reset();
         }
     sinfo_free_propertylist(&plist);
+    /*
     radangle = angle * PI_NUMB / 180. ;
     cd1_1 = cos(radangle) ;
     cd1_2 = sin(radangle) ;
     cd2_1 = -sin(radangle) ;
     cd2_2 = cos(radangle) ;
-    
+    */
     sinfo_msg("frame no.: %d, name: %s\n", n, name) ;
     cknull(im = cpl_image_load(name,CPL_TYPE_FLOAT,0,0),
            " could not load frame %s!",name) ;
@@ -762,9 +765,10 @@ int sinfo_new_objnod (const char* plugin_id,cpl_parameterlist* config,
     }
     sinfo_free_array_imagelist(&cubeobject);
 
-        newcenter_x = cfg->size_x / 2. + 0.5 ;
+    /*
+    newcenter_x = cfg->size_x / 2. + 0.5 ;
     newcenter_y = cfg->size_y / 2. + 0.5 ;
-
+    */
         ck0(sinfo_pro_save_ims(jittercube,sof,sof,cfg->outName,
                    procatg,NULL,plugin_id,config),
         "cannot save cube %s", cfg->outName);
