@@ -251,11 +251,11 @@ int sinfo_new_prepare_stacked_frames (const char* plugin_id,
     char file_name[MAX_NAME_SIZE];
     cpl_table* tbl_index = NULL;
     cpl_table* tbl_slitpos=NULL;
-    int rhead=0;
+    /* int rhead=0; */
 
     cpl_frame*     sky_frame = NULL;
     char* sky_name  = NULL;
-    char* sky_tag   = NULL;
+    /* char* sky_tag   = NULL; */
     qc_wcal* qc=sinfo_qc_wcal_new();
 
     cpl_parameter* p=NULL;
@@ -385,7 +385,7 @@ int sinfo_new_prepare_stacked_frames (const char* plugin_id,
     }
 
     /* up to here leak free */
-    rhead=0;
+    /* rhead=0; */
     for (i=0; i< cfg->nframes; i++) {
         typ = sinfo_new_intarray_get_value( cfg->frametype, i );
         pos = sinfo_new_intarray_get_value( cfg->frameposition, i );
@@ -420,7 +420,7 @@ int sinfo_new_prepare_stacked_frames (const char* plugin_id,
                                 (pdensity == 2 && frm_ind == 0)) {
                     check_nomsg(sky_frame = cpl_frameset_get_frame(raw,i));
                     check_nomsg(sky_name  = (char*) cpl_frame_get_filename(sky_frame));
-                    check_nomsg(sky_tag   = (char*) cpl_frame_get_tag(sky_frame));
+                    /* check_nomsg(sky_tag   = (char*) cpl_frame_get_tag(sky_frame)); */
 
                     if ( (strstr(frm_pro_ctg,"OBJECT") != NULL) ||
                                     (strstr(frm_pro_ctg,"PSF") != NULL) ||
