@@ -108,7 +108,7 @@ int sinfo_new_slit_pos (cpl_parameterlist* config, cpl_frameset* sof)
     wave_config * cfg =NULL;
     int check = 0;
     int lx = 0;
-    int ly = 0;
+    /* int ly = 0; */
     int n_lines=0;
     int i = 0;
     int j = 0;
@@ -156,7 +156,7 @@ int sinfo_new_slit_pos (cpl_parameterlist* config, cpl_frameset* sof)
     double fwhm_avg=0;
     double coef_med=0;
     double coef_avg=0;
-    int trow=0;
+    /* int trow=0; */
     qc_wcal* qc=sinfo_qc_wcal_new();
     /*        -----------------------------------------------------------------
        1) parse the file names and parameters to the ns_config data 
@@ -231,7 +231,7 @@ int sinfo_new_slit_pos (cpl_parameterlist* config, cpl_frameset* sof)
 
 
     lx = cpl_image_get_size_x(im);
-    ly = cpl_image_get_size_y(im);
+    /* ly = cpl_image_get_size_y(im); */
 
 
 
@@ -439,12 +439,12 @@ if (cfg->calibIndicator == 1 && cfg->wavemapInd == 0) {
             coef_avg=cpl_table_get_column_mean(tbl_wcal,col_name);
             coef_med=cpl_table_get_column_median(tbl_wcal,col_name);
 
-            trow=1+i;
+            //trow=1+i;
             snprintf(key_name,MAX_NAME_SIZE-1,"%s%d%s","QC COEF",i," AVG");
             ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,coef_avg,
                          "Average wavecal Coef","%g"));
 
-            trow=1+i+cfg->nrDispCoefficients;
+            //trow=1+i+cfg->nrDispCoefficients;
             snprintf(key_name,MAX_NAME_SIZE-1,"%s%d%s","QC COEF",i," MED");
             ck0_nomsg(sinfo_qclog_add_double(qclog_tbl,key_name,coef_med,
                          "Median wavecal Coef","%g"));
