@@ -142,7 +142,7 @@ sinfo_new_stdstar(const char* plugin_id,
     double fwhm_x=0;
     double fwhm_y=0;
     double disp=0;
-    double dispersion=0;
+    /* double dispersion=0; */
     int i=0;
     int wllx=0;
     int wlly=0;
@@ -165,9 +165,10 @@ sinfo_new_stdstar(const char* plugin_id,
     int no=0;
     double lo_cut=0.;
     double hi_cut=0.;
-
+    /*
     const char* stdstars=NULL;
     const char* sed=NULL;
+    */
     cpl_frame* frm_sci=NULL;
     cpl_frame* frm_atmext=NULL;
     cpl_frame* frm_std_cat=NULL;
@@ -203,10 +204,10 @@ sinfo_new_stdstar(const char* plugin_id,
      cknull(list_object = cpl_imagelist_new (),
        "could not allocate memory");
 
-
+    /*
     sed = sinfo_extract_filename(sof, SINFO_CALIB_SED) ;
     stdstars = sinfo_extract_filename(sof, SINFO_CALIB_STDSTARS) ;
-
+    */
 
     if (cfg->convInd == 1) {
       factor = sinfo_new_floatarray(cfg->nframes);
@@ -237,7 +238,7 @@ sinfo_new_stdstar(const char* plugin_id,
 
     cenpix = sinfo_pfits_get_crpix3(plist);
     cenLambda = sinfo_pfits_get_crval3(plist);
-    dispersion = sinfo_pfits_get_cdelt3(plist);
+    /* dispersion = sinfo_pfits_get_cdelt3(plist); */
 
 
     if (sinfo_propertylist_has(plist, KEY_NAME_CDELT3)) {
