@@ -638,7 +638,7 @@ sinfo_new_convert_0_to_ZERO_for_cubes_range(cpl_imagelist * cube,
                                             const int z_min,const int z_max)
 {
     int i ;
-    int inp=0;
+    //int inp=0;
     cpl_image* i_img=NULL;
 
     if ( cube == NULL )
@@ -646,7 +646,7 @@ sinfo_new_convert_0_to_ZERO_for_cubes_range(cpl_imagelist * cube,
         sinfo_msg_error("no input cube given!") ;
         return ;
     }
-    inp=cpl_imagelist_get_size(cube);
+    //inp=cpl_imagelist_get_size(cube);
     for ( i = z_min ; i < z_max ; i++ )
     {
       i_img=cpl_imagelist_get(cube,i);
