@@ -419,7 +419,7 @@ sinfo_new_fine_shift_image_in_spec_poly ( cpl_image * shiftedImage,
     int ilx=0;
     int ily=0;
     int olx=0;
-    int oly=0;
+    /* int oly=0; */
 
     float* pidata=NULL;
     float* podata=NULL;
@@ -447,7 +447,7 @@ sinfo_new_fine_shift_image_in_spec_poly ( cpl_image * shiftedImage,
     }
 
     olx=cpl_image_get_size_x(retIm);
-    oly=cpl_image_get_size_y(retIm);
+    /* oly=cpl_image_get_size_y(retIm); */
     podata=cpl_image_get_data_float(retIm);
 
     n_points = order + 1 ;
@@ -587,7 +587,7 @@ sinfo_new_fine_shift_image_in_spec_cubic_spline ( cpl_image * shiftedImage,
     int ilx=0;
     int ily=0;
     int olx=0;
-    int oly=0;
+    /* int oly=0; */
 
     float* pidata=NULL;
     float* podata=NULL;
@@ -608,7 +608,7 @@ sinfo_new_fine_shift_image_in_spec_cubic_spline ( cpl_image * shiftedImage,
         return NULL ;
     }
     olx=cpl_image_get_size_x(retIm);
-    oly=cpl_image_get_size_y(retIm);
+    /* oly=cpl_image_get_size_y(retIm); */
     podata=cpl_image_get_data_float(retIm);
 
     xnum=cpl_calloc(ily,sizeof(float)) ;
