@@ -565,7 +565,7 @@ sinfo_new_multiply_image_with_spectrum( cpl_image * image,
 
     int ilx=0;
     int ily=0;
-    int slx=0;
+    /* int slx=0; */
     int sly=0;
 
     float* pidata=NULL;
@@ -586,7 +586,7 @@ sinfo_new_multiply_image_with_spectrum( cpl_image * image,
         sinfo_msg_error(" no spectrum image given!") ;
         return NULL ;
     }
-    slx=cpl_image_get_size_x(spectrum);
+    /* slx=cpl_image_get_size_x(spectrum); */
     sly=cpl_image_get_size_y(spectrum);
 
     if ( sly != ily )
@@ -1789,7 +1789,11 @@ Vector * sinfo_new_blackbody_spectrum( char * templateSpec, double temp )
         /* convert from microns to m */
 
         lambda /= 1.0e6 ;
-        denom = 1./(exp(PLANCK*SPEED_OF_LIGHT/(lambda*BOLTZMANN*temp)) - 1.) ;
+        /* replaced 1./(exp(PLANCK*SPEED_OF_LIGHT/(lambda*BOLTZMANN*temp)) - 1.) 
+         * by 1./(expm1(PLANCK*SPEED_OF_LIGHT/(lambda*BOLTZMANN*temp))) 
+         * for better accuracy if argument of exponential is small 
+         */
+        denom = 1./(expm1(PLANCK*SPEED_OF_LIGHT/(lambda*BOLTZMANN*temp))) ;
         intens = 2.*PI_NUMB*PLANCK*SPEED_OF_LIGHT*SPEED_OF_LIGHT / 
                  pow(lambda, 5) * denom ;
         retSpec->data[n] = intens ;   
@@ -2394,7 +2398,7 @@ sinfo_new_div_image_by_spectrum( cpl_image * image, cpl_image * spectrum )
     int ilx=0;
     int ily=0;
 
-    int slx=0;
+    /* int slx=0; */
     int sly=0;
 
     float* pidata=NULL;
@@ -2415,7 +2419,7 @@ sinfo_new_div_image_by_spectrum( cpl_image * image, cpl_image * spectrum )
         sinfo_msg_error("no spectrum image given!") ;
         return NULL ;
     }
-    slx=cpl_image_get_size_x(spectrum);
+    /* slx=cpl_image_get_size_x(spectrum); */
     sly=cpl_image_get_size_y(spectrum);
 
     if ( sly != ily )
