@@ -563,21 +563,23 @@ cpl_imagelist * sinfo_new_cube_getvig(
 {
     cpl_imagelist     *        cube_out ;
     int                 i ;
+    /*
     int                 outlx,
                                         outly ;
 
     int ilx=0;
     int ily=0;
     int inp=0;
+    */
     cpl_image* i_img=NULL;
     cpl_image* o_img=NULL;
 
     if (cube_in==NULL) return NULL ;
-
+/*
     ilx=cpl_image_get_size_x(cpl_imagelist_get(cube_in,0));
     ily=cpl_image_get_size_y(cpl_imagelist_get(cube_in,0));
     inp=cpl_imagelist_get_size(cube_in);
-
+*/
         if ((loleft_x>upright_x) ||
             (loleft_y>upright_y)) {
             sinfo_msg_error("ill-defined slit for extraction: aborting");
@@ -585,8 +587,10 @@ cpl_imagelist * sinfo_new_cube_getvig(
         }
 
     /* Extraction coordinates include rectangular zone  */
+        /*
     outlx = upright_x - loleft_x + 1 ;
     outly = upright_y - loleft_y + 1 ;
+    */
     /*
     cube_out = sinfo_new_cube(outlx, outly, cube_in->np) ;
     */
@@ -1420,7 +1424,7 @@ cpl_imagelist** sinfo_new_sinfoni_correct_sky(cpl_imagelist** cubes,
 
 
   int sky_lx=0;
-  int sky_ly=0;
+  /* int sky_ly=0; */
 
   float* pidata=NULL;
   float* p_sky_data=NULL;
@@ -1438,7 +1442,7 @@ cpl_imagelist** sinfo_new_sinfoni_correct_sky(cpl_imagelist** cubes,
 
 
   sky_lx=cpl_image_get_size_x(cpl_imagelist_get(sky_cube,0));
-  sky_ly=cpl_image_get_size_y(cpl_imagelist_get(sky_cube,0));
+  /* sky_ly=cpl_image_get_size_y(cpl_imagelist_get(sky_cube,0)); */
   if ( nc <= 0 ) {
     sinfo_msg_error ("wrong number of data cubes in list!") ;
     return NULL ;
