@@ -18,7 +18,7 @@
  */
 /*
  * $Author: amodigli $
- * $Date: 2012/03/03 10:17:31 $
+ * $Date: 2012-03-03 10:17:31 $
  * $Revision: 1.17 $
  *
  */
@@ -523,7 +523,7 @@ sinfo_utl_efficiency_internal(
   double* peph = NULL;
 
   double* pw = NULL; // wavelength of the input table
-  double* pf = NULL; // flux of the input table
+  /* double* pf = NULL; // flux of the input table */
   int nrow = 0;
   double ref_bin_size=0;
 
@@ -561,7 +561,7 @@ sinfo_utl_efficiency_internal(
   check_nomsg(cpl_table_save(tbl_obj_spectrum,NULL,NULL,"sci2.fits",CPL_IO_DEFAULT));
   sinfo_msg("object 2 src std %g",src2ref_wave_sampling);
   check_nomsg(pw=cpl_table_get_data_double(tbl_obj_spectrum,col_name_obj_wave));
-  check_nomsg(pf=cpl_table_get_data_double(tbl_obj_spectrum,col_name_obj_flux));
+  /* check_nomsg(pf=cpl_table_get_data_double(tbl_obj_spectrum,col_name_obj_flux)); */
 
   // prepare columns for the output data
   check_nomsg(tbl_result=cpl_table_new(nrow));
@@ -675,7 +675,7 @@ sinfo_efficiency_compute(cpl_frame* frm_sci,
   double dEpsilon=0.1;
   double um2AA=1.e4;
 
-  int nrow=0;
+  /* int nrow=0; */
   int biny=1;
 
   const char* name_sci=NULL;
@@ -698,7 +698,7 @@ sinfo_efficiency_compute(cpl_frame* frm_sci,
           gain,airmass,exptime,airmass,dRA,dDEC);
 
   sinfo_msg("table sci spectra=%s",name_sci);
-  nrow=cpl_table_get_nrow(tbl_sci);
+  /* nrow=cpl_table_get_nrow(tbl_sci); */
 
   check_nomsg(name_atm=cpl_frame_get_filename(frm_atmext));
   check_nomsg(tbl_atmext=cpl_table_load(name_atm,1,0));
